Processor.App.OutStreamer.stream\_to\_file.OutStreamerFileDefault.metadata\_to\_string
======================================================================================

.. currentmodule:: Processor.App.OutStreamer.stream_to_file

.. automethod:: OutStreamerFileDefault.metadata_to_string